## 2020-科技新聞
### TechOrange
### 【頂好走入歷史】家樂福砸 32 億收購頂好，目標：成為全台規模第二大超市
| VIEW MORE »
### TechOrange 南極變「綠」了！全球暖化讓南極綠藻大量增生，將對氣候產生什麼影響？
| VIEW MORE »
|  | ### TechOrange 【配合中國政府要求】遊戲平台 Steam 推中國版，限制玩家的登入時間、實名資訊
| VIEW MORE »
### TechOrange 【半導體業今年最夯】台積電工程師年薪約 200 萬只排 14 ，IC 設計均薪逼近 300 萬
| VIEW MORE »
|  | ### TechOrange 【超過 2000 萬筆台灣人個資，在暗網上被販售】政院資安處：多數為舊資料
| VIEW MORE »
### TechOrange 韓國教授研發「深度學習」電子皮膚！只要裝在手腕上，就能推測手指的運動狀態
| VIEW MORE »
|  | ### TechOrange 【比機車還貴？】Gogoro 自推「智慧單車」要價 11.7 萬，其實捷安特更貴
| VIEW MORE »
### TechOrange 搶下華為訂單之後，中芯擬募資 800 億申請回歸上海 A 股
| VIEW MORE »
|  | ### TechOrange 台灣最早創立、上市的晶圓廠，聯電擁有全球最高的「面板驅動 IC」市佔率！
| VIEW MORE »
### TechOrange 美國 9 歲男孩發明紙牌遊戲，年賺超過 3000 萬台幣！
| VIEW MORE »
|  | ### TechOrange 訂閱制公司正在崛起！實體店變展示間，與消費者維持長期互惠關係
| VIEW MORE »
### TechOrange SpaceX 火箭升空！從發射細節、技術 demo 到周邊產業一次全解析
| VIEW MORE »
|  | ### TechOrange 台灣開放防疫 APP 程式碼，用「Taiwan can help」精神協助他國抗疫！
| VIEW MORE »
### TechOrange 【天空之上的千億商機】從「太空投資」來看，為何 SpaceX 載人任務將掀新型太空競賽?
| VIEW MORE »
|  | ### TechOrange 用「優惠機制」解決亂停問題，共享滑板車新創 Beam 獲得 2600 萬美元融資
| VIEW MORE »
### TechOrange 【5G 為什麼不可能取代 WiFi】建置成本讓資費調降困難，網速限制之下也可能比 WiFi 6 慢
| VIEW MORE »
|  | ### TechOrange 月球的水資源，為何是太空發展重要商機？
| VIEW MORE »
### TechOrange 【開大絕保護資安】印度人開發「移除中國程式」，能抓出中國 App 讓用戶刪除
| VIEW MORE »
|  | ### TechOrange 中國強化 IC 設計自主，可能引發台灣半導體業第三波人才出走潮
| VIEW MORE »
### TechOrange 解析思維陷阱「所羅門悖論」：為何人類能聰明論斷他人問題，對自己的處境卻無能為力？
| VIEW MORE »
|  | ### TechOrange 升級能源管理高效率！台達智慧綠能解決方案為何從 OT、IT 整合下手？
| VIEW MORE »
### TechOrange 【危機帶動生意】全球駭客攻擊增加衍生資安商機，ISE 資安指數兩個月暴漲 45%
| VIEW MORE »
|  | ### TechOrange 【被遺忘的歷史】蘇聯 70 年前就已經設立 AI Lab，還研發出能下西洋棋的 AI
| VIEW MORE »
### TechOrange 【科技報橘 2020 擴大徵才】和我們一起探索台灣該如何突破侷限、躍居國際產業要角的可能方案
| VIEW MORE »
|  | ### TechOrange 搶攻車用半導體市場，台積電推出 7 奈米汽車設計實現平台！
| VIEW MORE »
### iThome
### iThome 【科技抗疫實例：疾管署｜AILabs】電子圍籬系統有助落實居家檢疫，新版系統以App貫穿所有流程
| VIEW MORE »
|  | ### iThome 供應鏈攻擊鎖定GitHub開源軟體專案，讓開發人員上傳程式碼就一併植入後門程式
| VIEW MORE »
### iThome 綜所稅申報一個月，TW FidO行動身分識別使用人數已破萬
| VIEW MORE »
|  | ### iThome 【科技抗疫實例：工研院】靠AIoT改良紅外線體溫量測準度，不只政府自用還開放技轉
| VIEW MORE »
### iThome 內建硬體信任根與IPsec加速，Mellanox發表25GbE網路卡
| VIEW MORE »
|  | ### iThome 不滿對川普貼文的處置，臉書員工蘊釀罷工並威脅要離職
| VIEW MORE »
### iThome 【大話資安直播預告】你知道，臺灣半導體產業已經是APT攻擊鎖定對象了嗎？
| VIEW MORE »
|  | ### iThome 趨勢科技軟體驅動程式在微軟認證測試中作弊，被列入Windows 10黑名單
| VIEW MORE »
### iThome AI趨勢周報第133期：35億張照片訓練而成！臉書亮相通用商品辨識AI
| VIEW MORE »
|  | ### iThome 是誰在大量操縱訊息？Google公布首個協作影響力行動公告
| VIEW MORE »
### iThome 開發者社群Stack Overflow年度調查：Rust第五年蟬聯最愛程式語言排行榜冠軍
| VIEW MORE »
|  | ### iThome 【科技抗疫實例：Gemini Data】靠知識圖譜工具將疫調數據視覺化，更快找出確診者關聯性
| VIEW MORE »
### iThome 全球第三大內容管理平臺Joomla的備份不設防，2,700名合作夥伴的資訊全曝光
| VIEW MORE »
|  | ### iThome 臺灣2千萬筆戶政資料暗網兜售？行政院資安處：非戶政資料，多方舊資料庫整併
| VIEW MORE »
### iThome 微軟終於承認欠AppGet一個謝字，但未提道歉
| VIEW MORE »
|  | ### iThome VS Code Java擴充套件更新，狀態列會顯示專案最低JDK要求
| VIEW MORE »
### iThome 臺灣科技防疫經驗，全球搶借鏡
| VIEW MORE »
|  | ### iThome 【科技抗疫實例：北醫附醫、工研院】4關鍵科技實現高風險照護零接觸，本土先實證再搶攻海外需求
| VIEW MORE »
### iThome 一周大事：蔡英文：資安成為新政府重點核心戰略產業。開放銀行第二階段Q3上路
| VIEW MORE »
|  | ### iThome ACLU控告Clearview AI侵犯隱私
| VIEW MORE »
### iThome 臺灣逾2,000萬民眾個資在暗網中流傳
| VIEW MORE »
|  | ### iThome 思科買下SaaS網路效能監控業者ThousandEyes
| VIEW MORE »
### iThome Docker和微軟合作要簡化容器應用程式開發與部署
| VIEW MORE »
|  | ### iThome 明年Google搜尋將把網頁經驗納入排序依據
| VIEW MORE »
### iThome 【科技抗疫實例：衛福部、臺北榮總】放寬遠距醫療適用對象，641次高風險看診醫病免接觸
| VIEW MORE »
|  | ### iThome 樹莓派4最新8 GB版本售價75美元
| VIEW MORE »
### iThome Google運用聯合分析技術，可保護用戶隱私又能改善服務品質
| VIEW MORE »
|  | ### iThome Google、微軟合作開發瀏覽器拼字檢查功能
| VIEW MORE »
### iThome 臺灣戶政資料傳出外洩疑雲，行政院資安處揭露更多細節，強調與戶政單位無關
| VIEW MORE »
|  | ### iThome 微軟Windows Package Manger爆抄襲對手
| VIEW MORE »
### iThome Red Hat Runtimes加入Quarkus框架支援K8s原生Java開發
| VIEW MORE »
|  | ### iThome 臺灣公開2支超前部署防疫App，將提供原始碼供外國政府防疫
| VIEW MORE »
### iThome 科技防疫在臺灣
| VIEW MORE »
|  | ### iThome 【科技抗疫實例：MyData Taiwan】臺灣自主健康管理工具登場，堅持找出防疫追蹤和隱私的平衡
| VIEW MORE »
### iThome 電腦若因相容性無法升級，Windows 10 May 2020 Update將發出通知
| VIEW MORE »
|  | ### iThome 【科技抗疫實例：行政院｜AILabs】4月完成臺版社交距離App，疫情趨緩未上線改支援國外防疫
| VIEW MORE »
### iThome 蘋果釋出iOS 13.5.1以修補被unc0ver拿來越獄的安全漏洞
| VIEW MORE »
|  | ### iThome 研究人員準備開源USB驅動程式漏洞測試工具USBFuzz
| VIEW MORE »
### iThome 微軟裁掉新聞編輯，以AI取代
| VIEW MORE »
|  | ### iThome 開源遊戲引擎Godot應用最新網頁技術，將遊戲編輯器搬上瀏覽器
| VIEW MORE »
### iThome 卡內基美隆大學研究顯示，許多人對網站密碼外洩通知無感，僅3成會在收到官方通知後確實變更密碼
| VIEW MORE »
|  | ### iThome 美國安局警告，俄羅斯駭客正在開採Exim漏洞
| VIEW MORE »
### iThome 駭客藉由SaltStack漏洞入侵思科伺服器
| VIEW MORE »
|  | ### iThome 第一季全球智慧型手機市場衰退20%，史上最嚴重
| VIEW MORE »
### iThome 這些科技，加速臺灣撐過疫情
| VIEW MORE »
|  | ### iThome 美國發生大規模反種族暴力抗議行動，Google宣布Android 11 beta版延後釋出
| VIEW MORE »
### iThome NTT代管服務網路被駭，621家客戶公司資料疑外流
| VIEW MORE »
|  | ### iThome AWS Amplify現提供iOS和Android原生函式庫
| VIEW MORE »
### iThome 擴大打擊假資訊，臉書要求文章瘋傳的帳號驗證身分
| VIEW MORE »
|  | ### iThome HackerOne成立8年來已頒發1億美元抓漏獎金，預計只需5年就能突破10億美元門檻
| VIEW MORE »
### iThome Android Studio最新4.0釋出，加入Motion動畫編輯器
| VIEW MORE »
|  | ### iThome Chrome 84將開始封鎖遭濫用的網站通知
| VIEW MORE »
### iThome Google Cloud Functions開始支援Java 11
| VIEW MORE »
|  | ### iThome 掌握多雲環境資產、法規與政策控管，FireEye推單一資安方案
| VIEW MORE »
### iThome 蘋果Sign In with Apple爆可被劫持帳號的漏洞
| VIEW MORE »
|  | ### iThome 開放銀行第二階段Q3上路，18支消費者資訊開放API和規範細節終於公開
| VIEW MORE »
### iThome 【科技抗疫實例：衛福部、DeepQ】跨部會攜手企業打造居家關懷系統，每日追蹤數萬人健康狀況
| VIEW MORE »
|  | ### iThome 川普簽署行政命令以去除社交網站的保護傘
| VIEW MORE »
### iThome 最新Valak惡意程式可竊取Exchange伺服器憑證
| VIEW MORE »
|  | ### iThome 因美國示威暴動頻傳，思科Cisco Live年度線上會議於召開前夕喊停，將延後舉行
| VIEW MORE »
### 數位時代
### 仁寶用5G實驗室操兵，為何說智慧農業、智慧製造應用將跑最前頭？
| VIEW MORE »
### 數位時代 100億救命資金到位後，最神秘AR公司Magic Leap執行長將離職
| VIEW MORE »
|  | ### 數位時代 5G拚準時開台！全年擴大招募1,600人，中華電信如何瞄準營收「新」動能？
| VIEW MORE »
### 數位時代 友訊李中旺當選2周董事長，卻進不去總部，獨董罵：「死的鴨子嘴還是硬的！」
| VIEW MORE »
|  | ### 數位時代 網紅是真正的KOL嗎？
| VIEW MORE »
### 數位時代 SpaceX載人上太空，馬斯克領導力受肯定！特斯拉飆7%、太空相關走強
| VIEW MORE »
|  | ### 數位時代 5G應用如何不卡卡？Arm推新解決方案，靠運算力推一把
| VIEW MORE »
### 數位時代 一站串起最佳路徑！他創辦網路界Google Maps，讓連線加速不中斷
| VIEW MORE »
|  | ### 數位時代 另一半也能客製化？新創Hybri開放募資，打造虛擬情人服務
| VIEW MORE »
### 數位時代 全球掃描：假訊息比病毒更令印度頭痛／獲選最佳領袖，李文亮微博卻成了一道哭牆
| VIEW MORE »
|  | ### 數位時代 出海也有超高「容錯性」！在地團隊成熟前，FunNow靠這招迅速調整決策方向
| VIEW MORE »
### 數位時代 訂閱制起飛！Spotify、Netflix之外，這4種服務也用「月費」方式改變市場
| VIEW MORE »
|  | ### 數位時代 劉揚偉新布局！鴻海與凌華合資機器人公司，拍板關鍵在5年前的一場併購
| VIEW MORE »
### 數位時代 SpaceX為太空時代翻新頁！龍飛船成功載人升空，「宇宙旅行」明年登場
| VIEW MORE »
|  | ### 數位時代 台北人夜未眠地標「誠品敦南」將熄燈！吳旻潔：某種程度就像吳清友的離開一樣
| VIEW MORE »
### 數位時代 與哈佛醫學院合作過！最懂醫療研究者的Kiipo返台創業，讓數據搜集不再難
| VIEW MORE »
|  | ### 數位時代 一日檢驗10萬顆高爾夫球！ 慧穩科技將AI深度學習入門台灣工業4.0
| VIEW MORE »
### 數位時代 空前絕後的軟銀願景基金，死於錢多？
| VIEW MORE »
|  | ### 數位時代 怒嗆「FB搞我！」486先生、吳念真粉專無預警被消失，Facebook出什麼問題？
| VIEW MORE »
### 數位時代 美國暴動引發零售業新威脅！Nike、愛迪達、Walmart等數百門市關閉中
| VIEW MORE »
|  | ### 數位時代 SHOPLINE開通海外3,000家小七取貨，助台灣電商搶灘東南亞大餅
| VIEW MORE »
### 數位時代 王品徵才500人、繼光香香雞加薪5%，餐飲業走出疫情谷底了？
| VIEW MORE »
|  | ### 數位時代 華為找人「代購」台積晶片避禁令？聯發科被點名，急發重訊駁斥
| VIEW MORE »
### 數位時代 2020最強零售通路！超商可以賣口罩、報稅，還有什麼做不到？
| VIEW MORE »
|  | ### 數位時代 直擊！仁寶首次公開的5G實驗室，究竟有什麼看頭？
| VIEW MORE »
### 數位時代 川普威脅軍事鎮壓！Uber、Lyft、DoorDash配合宵禁暫停營運
| VIEW MORE »
|  | ### 數位時代 +0又來了！指揮中心再公布防疫物資數量，口罩累計販售7億片
| VIEW MORE »
### 數位時代 一個逝去的靈魂，讓Spotify播8分46秒無聲音訊、Nike金句換成「Don’t do it」、Google換上黑絲帶
| VIEW MORE »
|  | ### 數位時代 詹宏志、唐鳳對談：數位新國際秩序正在成形，發現台灣新外交標誌！
| VIEW MORE »
### 數位時代 三天內增4萬好友！HBL史上第一次小巨蛋封館開打，NIKE如何做到零人入場、萬人應援？
| VIEW MORE »
|  | ### 數位時代 劉揚偉、陳其宏產業大咖同框！談後疫情時代的3個關鍵挑戰
| VIEW MORE »
### 數位時代 從1,300元跌到40塊不到！HTC新執行長曾大談「時機論」，上任不滿一年就裁員兩次
| VIEW MORE »
|  | ### 數位時代 AAMA正式網羅200位成長期創業者！今年AI應用、IOT、MarTech、文創設計領域突圍入選
| VIEW MORE »
### 數位時代 《產業領袖觀點》疫情前夕剛吞下Fujiiryoki品牌，喬山跨過300億元營收後如何挑戰健身器材龍頭？
| VIEW MORE »
|  | ### 數位時代 友訊股東常會6月15日舉行，臨時會6月1日合法召開獲地院、高院雙認證
| VIEW MORE »
### 數位時代 跟打字機說再見！當劇作家都在用電腦寫故事，用編劇軟體該注意什麼？
| VIEW MORE »
|  | ### 數位時代 一場回不了頭的產業轉型實驗
| VIEW MORE »